import { Plugin } from "@webiny/plugins";
import WebinyError from "@webiny/error";

export interface ValueFilterPluginParamsMatchesParams<V = any, C = any> {
    value: V;
    compareValue: C;
}

export interface ValueFilterPluginParamsMatches {
    (params: ValueFilterPluginParamsMatchesParams): boolean;
}

export interface ValueFilterPluginParams {
    operation: string;
    matches: ValueFilterPluginParamsMatches;
}
export class ValueFilterPlugin extends Plugin {
    public static override readonly type: string = "dynamodb.value.filter";
    private readonly _params: ValueFilterPluginParams;

    public get operation(): string {
        return this.getOperation();
    }

    public constructor(params: ValueFilterPluginParams) {
        super();
        this._params = params;
    }

    public matches(params: ValueFilterPluginParamsMatchesParams): boolean {
        if (!this._params || !this._params.matches) {
            throw new WebinyError(`Missing "matches" in the plugin.`, "MATCHES_ERROR", {
                plugin: this,
                params
            });
        }
        return this._params.matches(params);
    }

    public getOperation(): string {
        if (!this._params || !this._params.operation) {
            throw new WebinyError(`Missing "operation" in the plugin.`, "OPERATION_ERROR");
        }
        return this._params.operation;
    }
}
